"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = (api, opts, preset) => {
    const conf = {
        root: true,
        env: { node: true },
        extends: ['plugin:vue/essential'],
        parserOptions: {
            ecmaVersion: 2020,
        },
        rules: {
            'no-console': api.makeJSOnlyValue(`process.env.NODE_ENV === 'production' ? 'warn' : 'off'`),
            'no-debugger': api.makeJSOnlyValue(`process.env.NODE_ENV === 'production' ? 'warn' : 'off'`),
        },
    };
    if (api.hasPlugin('babel') && !api.hasPlugin('typescript')) {
        conf.parserOptions = {
            parser: '@babel/eslint-parser',
        };
    }
    const { config } = opts;
    if (config === 'airbnb') {
        conf.extends.push('@vue/airbnb');
    }
    else if (config === 'standard') {
        conf.extends.push('@vue/standard');
    }
    else if (config === 'prettier') {
        conf.extends.push(...['eslint:recommended', '@vue/prettier']);
    }
    else {
        // default
        conf.extends.push('eslint:recommended');
    }
    if (api.hasPlugin('typescript')) {
        // typically, typescript ruleset should be appended to the end of the `extends` array
        // but that is not the case for prettier, as there are conflicting rules
        if (config === 'prettier') {
            conf.extends.pop();
            conf.extends.push(...['@vue/typescript/recommended', '@vue/prettier', '@vue/prettier/@typescript-eslint']);
        }
        else {
            conf.extends.push('@vue/typescript/recommended');
        }
    }
    if (preset.vueVersion === '3') {
        const updateConfig = (cfg) => cfg.replace(/plugin:vue\/(essential|recommended|strongly-recommended)/gi, 'plugin:vue/vue3-$1');
        conf.extends = conf.extends.map(updateConfig);
    }
    /* 自定义配置 */
    // const customEslint = api.makeJSOnlyValue(`require.resolve('vue-cli-plugin-extend-base/lib/eslint/options')`);
    // delete conf.extends[customEslint];
    // conf.extends.push(customEslint);
    return conf;
};
