"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const index_1 = require("../index");
/**
 * 删除文件，不包括 .gitkeep
 * @param file
 */
const deleteFile = (file) => {
    if (fs_1.default.statSync(file).isFile() && !file.endsWith('.gitkeep')) {
        fs_1.default.unlinkSync(file);
    }
};
/**
 * 删除文件，不包括 .gitkeep
 * @param file
 */
const deleteDir = (file) => {
    if (fs_1.default.existsSync(file) && fs_1.default.statSync(file).isDirectory()) {
        let files = [];
        files = fs_1.default.readdirSync(file);
        files.forEach((path) => {
            const curPath = `${file}/${path}`;
            if (fs_1.default.statSync(curPath).isDirectory()) {
                // eslint-disable-next-line @typescript-eslint/no-unused-vars
                deleteDir(curPath);
            }
            else {
                deleteFile(curPath);
            }
        });
        fs_1.default.rmdirSync(file);
    }
};
/**
 * VUE Generator 扩展
 * @param api GeneratorAPI 实例
 * @param opts 插件配置选项
 * @param preset 当前使用预设
 */
exports.default = (api, opts, preset) => {
    /*  invoke 后会自动补充配置项至 vue.config.js 或者 package.json 内 */
    const mergeOpts = { ...index_1.DEFAULT_BASE_PLUGIN_OPTION, ...opts };
    if (!mergeOpts.registry) {
        delete mergeOpts.registry;
    }
    const { forkTsChecker, crossEnvVersion, ...rest } = mergeOpts;
    api.extendPackage({
        vue: {
            pluginOptions: {
                extendBase: {
                    forkTsChecker: forkTsChecker && Object.keys(forkTsChecker).length > 0 ? forkTsChecker : {},
                    ...rest,
                },
            },
        },
    });
    /* 环境变量依赖 */
    api.extendPackage({
        devDependencies: {
            'cross-env': crossEnvVersion,
        },
    });
    /* eslint扩展配置 */
    if (api.hasPlugin('eslint')) {
        api.extendPackage({
            eslintConfig: {
                extends: [api.makeJSOnlyValue(`require.resolve('vue-cli-plugin-extend-base/lib/eslint/options')`)],
            },
        });
    }
    const baseUrl = process.env.BASE_URL || '/';
    const data = { APP_BASE: baseUrl, BASE_URL: baseUrl };
    /* 渲染模板 */
    api.render('./template', data, {});
    api.postProcessFiles((files) => { });
    api.afterInvoke(() => {
        deleteDir(api.resolve('src/views'));
        deleteDir(api.resolve('src/components'));
        const pkgFile = api.resolve('package.json');
        const contentMain = fs_1.default.readFileSync(pkgFile, { encoding: 'utf-8' });
        const lines = contentMain.split(/\r?\n/g);
        const renderIndex = lines.findIndex((line) => line.match(/vue-cli-service serve/) && line.match(/"serve"/));
        if (renderIndex > 0) {
            lines[renderIndex] = lines[renderIndex].replace(/serve/, 'start');
            const { EOL } = require('os');
            fs_1.default.writeFileSync(pkgFile, lines.join(EOL), { encoding: 'utf-8' });
        }
    });
};
