"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_BASE_PLUGIN_OPTION = void 0;
/**
 * 默认插件配置
 */
exports.DEFAULT_BASE_PLUGIN_OPTION = {
    eslint: false,
    forkTsChecker: true,
    crossEnvVersion: '^7.0.3',
};
/**
 * 全局自定义变量
 * @param config
 * @param opts
 */
const customDefineGlobalVariable = (config, opts) => {
    const webpack = require('webpack');
    const prefixREG = /^APP_/;
    const env = {};
    Object.keys(process.env).forEach((key) => {
        if (prefixREG.test(key)) {
            env[key] = process.env[key];
        }
    });
    for (const key in env) {
        env[key] = JSON.stringify(env[key]);
    }
    const { version, port, baseUrl, mocked } = opts;
    /* 1.添加全局变量 */
    config.plugin('custom-define').use(webpack.DefinePlugin, [
        {
            ...env,
            APP_VERSION: JSON.stringify(version),
            APP_PORT: JSON.stringify(port),
            APP_BASE: JSON.stringify(baseUrl),
            BASE_URL: JSON.stringify(baseUrl),
            MOCK: JSON.stringify(mocked),
        },
    ]);
};
/**
 * TS 检查校验
 * @param config
 * @param forkTsChecker
 */
const forkTsVerify = (config, forkTsChecker) => {
    /* 5. fork-ts-checker 插件配置 */
    if (forkTsChecker) {
        /* 修改 fork-ts-checker 插件，导致无.vue后缀的组件导入错误 */
        if (Object.keys(forkTsChecker).length === 0) {
            config.plugins.get('fork-ts-checker').tap((args) => {
                const [options] = args;
                const { typescript: { extensions, diagnosticOptions }, } = options;
                const result = {
                    typescript: {
                        extensions,
                        diagnosticOptions: { ...diagnosticOptions, semantic: false },
                    },
                };
                return [result];
            });
        }
        else {
            config.plugins.get('fork-ts-checker').tap(() => [forkTsChecker]);
        }
    }
    else {
        /* 或者直接删除 */
        config.plugins.delete('fork-ts-checker');
    }
};
/**
 * service 插件
 * @param api
 * @param projectOptions
 */
exports.default = (api, projectOptions) => {
    const { pluginOptions } = projectOptions || {};
    const extendBase = pluginOptions.extendBase || {};
    const { eslint, forkTsChecker } = extendBase;
    api.chainWebpack((config) => {
        const version = process.env.APP_VERSION || require(`${api.getCwd()}/package.json`).version;
        const port = Number(process.env.APP_PORT || 8080);
        const baseUrl = String(process.env.BASE_URL || '/');
        const mocked = Boolean(process.env.MOCK || false);
        customDefineGlobalVariable(config, { version, port, baseUrl, mocked });
        /* 2.开发环境配置 */
        config.devServer.open(true).port(port).hot(true);
        /* 3.依据环境变量同步修改 publicPath */
        projectOptions.publicPath = baseUrl;
        config.output.publicPath(baseUrl);
        /* 4.移除 eslint 检查，改为 git hook 时进行检查 */
        if (!eslint) {
            config.module.rules.delete('eslint');
        }
        /* 5. fork-ts-checker 插件配置 */
        forkTsVerify(config, forkTsChecker);
    });
};
